@@ -24,7 +24,9 @@
 
 # limitations under the License. 
 
+from genericpath import exists
 import os.path
+from pathlib import Path
 
 def readLinesFromFile(fileName, folder = None, removeNewline = True):
     fileNameWithPath = fileName
@@ -51,4 +53,26 @@ def snippetExistsInFile(snippetLines, fileLines):
     for i in range(0, len(fileLines) - len(snippetLines) + 1):
         if fileLines[i:i+len(snippetLines)] == snippetLines:
             return True
-    return False
\ No newline at end of file
+    return False
+
+def path_exists_case_sensitive(path, parent_path = ""):
+    if (parent_path != ""):
+        fullOSPath = os.path.join(parent_path, path)
+    else:
+        fullOSPath  = path
+        
+    fullPath = Path(fullOSPath)
+    if (not fullPath.exists()):
+        return False
+        
+    currentPath = fullPath.resolve()
+    i = 0
+    while (currentPath != currentPath.parent):
+        found = False
+        for child in currentPath.parent.iterdir():
+            if (child.name == currentPath.name):
+                found = True
+        if (not found):
+            return False
+        currentPath = currentPath.parent
+    return True
\ No newline at end of file
